function [tipo_QRS,patrones,num_complejos] = ClasificaComplejos(QRS)
%[tipo_QRS,patrones,num_complejos] = ClasificaComplejos(QRS)
%
%Esta funcin clasifica una serie de complejos QRS en distintos patrones
%segn su morfologa. Para ello emplea el siguiente algoritmo: para cada
%QRS de la matriz de entrada, identifica el patrn correspondiente entre
%los patrones detectados hasta el momento. Si no se corresponde con ningn
%patrn conocido, entonces aade un nuevo patrn y lo asigna al QRS actual.
%En caso contrario, si efectivamente se encuentra entre los patrones
%existentes, actualiza el patrn correspondiente con el QRS actual. 
%
%   Entrada:
%       QRS [matriz]: secuencia de complejos QRS organizados en filas
%
%   Salida:
%       tipo_QRS [vector]:       clasificacin de cada complejo
%       patrones [matriz]:       conjunto de patrones detectados (en filas)
%       num_complejos [vector]:  nmero de complejos identificados de cada patrn
%
%   Llamadas a otras funciones:
%       IdentificaPatron
%patrones(1,:)=QRS(1,:);
%for i =1:size(QRS,1)
%    p = IdentificaPatron(patrones,QRS,umbral);
%n_complejos = size(QRS,2); 
patrones= [];
num_complejos = [];
for i=1:size(QRS,1)
    p = IdentificaPatron(patrones,QRS(i,:));
    
    if p>0  % asigna patron a complejo y actualiza patron actual
        
        tipo_QRS(i) = p;    
        patrones(p,:) = ((patrones(p,:)*(num_complejos(p)/(num_complejos(p)+1))+QRS(i,:)/(num_complejos(p)+1)));
        num_complejos(p) = num_complejos(p) + 1;
    else                % crea nuevo patrn y asigna patrn a complejo
        patrones = [patrones; QRS(i,:)];
        [N_patrones,N_col] = size(patrones);
        tipo_QRS(i) = N_patrones;
        num_complejos = [num_complejos; 1];
    end
end

