function p = IdentificaPatron(patrones,QRS,umbral)
%   p = IdentificaPatron(patrones,QRS,umbral)
%
%   Esta funcin identifica el patrn al que corresponde un complejo QRS
%   dado. En el caso de que el QRS no corresponda a ningn tipo de patrn 
%   perteneciente al conjunto de patrones, la funcin devuelve p=0
%   
%   Parmetros de entrada
%       patrones [matriz]:   conjunto de patrones de QRS organizados en filas
%       QRS [vector]:        QRS actual 
%
%   Parmetro de entrada opcional:
%       umbral [real]:       umbral de correlacin para la comparacin de patrones (entre 0 y 1)
%   
%   Parmetro de salida
%       p [entero]:          ndice correspondiente al tipo de patrn identificado
%
%   
if nargin <3 
    umbral = 0.8;
end

if isempty(patrones)
    p=0;
else
    for i=1:size(patrones,1)
        correlacion(i) = corr2(QRS,patrones(i,:));
    end
if correlacion < umbral
    p=0;
    patrones(size(patrones,1)+1,:)=QRS;
else
    max_cor = max(correlacion);

    p = find( correlacion == max(correlacion));
end
end




