
function classifyResult = challenge(recordName)

% Sample entry for the 2017 PhysioNet/CinC Challenge.
%
% INPUTS:
% recordName: string specifying the record name to process
%
% OUTPUTS:
% classifyResult: integer value where
%                     N = normal rhythm
%                     A = AF
%                     O = other rhythm
%                     ~ = noisy recording (poor signal quality)
%
% To run your entry on the entire training set in a format that is
% compatible with PhysioNet's scoring enviroment, run the script
% generateValidationSet.m
%
% The challenge function requires that you have downloaded the challenge
% data 'training_set' in a subdirectory of the current directory.
%    http://physionet.org/physiobank/database/challenge/2017/
%
% This dataset is used by the generateValidationSet.m script to create
% the annotations on your training set that will be used to verify that
% your entry works properly in the PhysioNet testing environment.
%
%
% Version 1.0
%
%
% Written by: Chengyu Liu and Qiao Li January 20 2017
%             chengyu.liu@emory.edu  qiao.li@emory.edu
%
% Last modified by:
%
%

%classifyResult = 'N'; % default output normal rhythm

%%Leemos Seal
[tm,ecg,fs,siginfo]=rdmat(recordName);
%Sacamos QRS
[R,sign,en_thres] = qrs_detect2(ecg',0.25,0.6,fs);

 if  isempty(R)
      ecg = ecg*1000;
      [R,sign,en_thres] = qrs_detect2(ecg,0.25,0.6,fs);
      ecg = ecg/1000;
      [latidos,lim_vent,Rn] = enventana_QRS(ecg,R,fs,60,350);    
 else
      [latidos,lim_vent,Rn] = enventana_QRS(ecg,R,fs,60,350);
 end
%if length(QRS)<6
%else
%    RR=diff(QRS')/fs;
%    AFEv = comput_AFEv(RR);
%   if AFEv>1
%        classifyResult = 'A';
%    end
%end
%Sacamos varianzas 1 y 2 de las distancias picos RR
[SD1, SD2] = var_12(R,fs);
%Sacamos medias 1 y 2 de las distancias picos RR
[M1, M2] = mean_12(R,fs);
%Sacamos RMSSD intervalo RR
[RMSSDRR] = RMSSD_RR(R,fs);
%Sacamos cienHR y doscienHR
[cienHR] = cien_HR(R,fs);
%Sacamos parmetros espectrales
[ecgout, amp,f] = fdetec(ecg, fs,lim_vent,latidos);
load modelos;
[meancorr, varcorr] = corrondaf( modelos,amp,f);
%Sacamos FFTstd
[FFTstd] = FFT_std_Signal(ecg,fs);
%Sacamos stdRR
[stdRR] = std_RR(R,fs);

%Aplicamos el modelo clasificaador
parametros=table(FFTstd', cienHR', RMSSDRR', stdRR', meancorr', varcorr', SD1', SD2', M1', M2','VariableNames',{ 'FFTstdSenyal' 'cienhr' 'RMSSD' 'stdRR' 'meancorr' 'varcorr' 'SD1' 'SD2' 'M1' 'M2'} );
% parametros=table(FFTstd', cienHR', RMSSDRR', stdRR', corre,'VariableNames',{ 'FFTstdSenyal' 'cienhr' 'RMSSD' 'stdRR' 'corre'} );
load MM1;
clase = MM1.predictFcn(parametros);

%Y segn la clase predicha clasificamos
if clase==1
    classifyResult='N';
end
if clase==2
    classifyResult='A';
end
if clase==3
    classifyResult='O'; 
end

%% You can add the determination rules for other rhythm and noisy recordings here

